@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2022 Pier Carlo Chiodi
+# Copyright (C) 2017-2023 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -119,14 +119,14 @@ class ValidatorASSet(ValidatorText):
         # At least one component of such a name must be an actual
         # set name (i.e. start with one of the prefixes above)."
         # https://datatracker.ietf.org/doc/html/rfc2622#section-5
-        if re.match("^AS[\d]+$", macro):
+        if re.match(r"^AS[\d]+$", macro):
             return macro
 
         as_dash_found = False
         parts = []
         for part in macro.split(":"):
             name = part.strip().upper()
-            if not re.match("^(?:AS[\d]+|AS-[A-Z0-9_\-]*[A-Z0-9])$", name):
+            if not re.match(r"^(?:AS[\d]+|AS-[A-Z0-9_\-]*[A-Z0-9])$", name):
                 raise ConfigError("invalid name {}".format(name))
             if name.startswith("AS-"):
                 as_dash_found = True
@@ -152,6 +152,17 @@ class ValidatorASN(ConfigParserValidator):
         except ConfigError:
             raise ConfigError("Invalid ASN: {}".format(v))
 
+class ValidatorPrivateASN16bit(ConfigParserValidator):
+
+    def _validate(self, v):
+        try:
+            asn = ValidatorUInt().validate(v)
+            if asn < 64512 or asn > 65534:
+                raise ConfigError()
+            return asn
+        except ConfigError:
+            raise ConfigError("Invalid private 16bit ASN: {}".format(v))
+
 class ValidatorASNList(ConfigParserValidator):
 
     def _validate(self, v):
@@ -448,6 +459,19 @@ class ValidatorMaxASPathLen(ConfigParserValidator):
                 "between 1 and 64"
             )
 
+class ValidatorRole(ConfigParserValidator):
+
+    # To keep in sync with to_bgp_role in builder.py
+    VALID_ROLES = ("provider", "rs", "rs-client", "customer", "peer")
+
+    def _validate(self, v):
+        if v.lower() in self.VALID_ROLES:
+            return v.lower()
+        else:
+            raise ConfigError(
+                "Invalid role: {}. Must be one of " + ", ".join(self.VALID_ROLES)
+            )
+
 class ValidatorCommunity(ConfigParserValidator):
 
     EXPECTED_PARTS_CNT = None
