@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2022 Pier Carlo Chiodi
+# Copyright (C) 2017-2023 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,26 @@ import logging
 import os
 import sys
 import unittest
+import requests_mock
+import json
+
+
+def setup_requests_mock():
+    res = requests_mock.Mocker()
+    res.start()
+    res.get(
+        "https://www.peeringdb.com/api/net?info_never_via_route_servers=1",
+        json={}
+    )
+    res.get(
+        "https://www.peeringdb.com/api/net?asn__in=3333,10745,197000",
+        json=json.load(open("tests/static/data/peeringdb_net_3333_10745.json"))
+    )
+    res.get(
+        "http://irrexplorer.nlnog.net/static/dumps/arin-whois-originas.json.bz2",
+        content=open("tests/static/data/arin-whois-originas.json.bz2", "br").read()
+    )
+    return res
 
 
 class CaptureLog(logging.Handler):
@@ -46,6 +66,7 @@ class CaptureLog(logging.Handler):
         finally:
             self.release()
 
+
 class ARouteServerTestCase(unittest.TestCase):
 
     NEED_TO_CAPTURE_LOG = False
@@ -79,6 +100,8 @@ class ARouteServerTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
+        # Prevent actual calls to external APIs.
+        cls.requests_mock = setup_requests_mock()
         cls._setUpClass()
 
     @classmethod
@@ -87,6 +110,7 @@ class ARouteServerTestCase(unittest.TestCase):
 
     @classmethod
     def tearDownClass(cls):
+        cls.requests_mock.stop()
         cls._tearDownClass()
 
     @classmethod
@@ -100,6 +124,7 @@ class ARouteServerTestCase(unittest.TestCase):
 
     @classmethod
     def info(cls, s):
+        cls.print_msg("")
         cls.print_msg(s)
 
     def shortDescription(self):
